==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-angular-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CustomIndicator = /*@__PURE__*/ (() => {
    class CustomIndicator extends StrategyBasedIndicator {
        constructor() {
            super(...arguments);
            this.zk = null;
            this.zj = null;
        }
        get_yy() {
            return new CustomIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return CustomIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        ya(a, b) {
            let c = this.um(a, b);
            let d = this.un(c);
            let e = new List$1(String_$type, 0);
            if (this.basedOnColumns != null) {
                let f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
                this.basedOnColumns(this, f);
                if (f.basedOn != null) {
                    for (let g of fromEnum(f.basedOn)) {
                        e.add(g);
                    }
                }
            }
            return e;
        }
        get indicator() {
            return this.zk;
        }
        set indicator(a) {
            this.zk = a;
            this.yi();
        }
        get basedOnColumns() {
            return this.zj;
        }
        set basedOnColumns(a) {
            this.zj = a;
        }
        x7(a, b) {
            super.x7(a, b);
            if (this.indicator != null) {
                let c = this.um(a, b);
                if (b == 0) {
                    return false;
                }
                if (!this.vi(this.ya(a, b))) {
                    return false;
                }
                this.indicator(this, new FinancialEventArgs(a, b, c, this.un(c), this));
                if (this.y0(c) && this.uv != null) {
                    this.uv.c1();
                }
                return true;
            }
            return false;
        }
    }
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
})();

==> igniteui-angular-charts-18.2.0-beta.0.tgz: package/esm2015/lib/CustomIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CustomIndicatorStrategy } from "./CustomIndicatorStrategy";
import { String_$type, fromEnum, markType } from "igniteui-angular-core";
import { FinancialEventArgs } from "./FinancialEventArgs";
import { List$1 } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CustomIndicator = /*@__PURE__*/ (() => {
    class CustomIndicator extends StrategyBasedIndicator {
        constructor() {
            super(...arguments);
            this.acf = null;
            this.ace = null;
        }
        bj() {
            return new CustomIndicator();
        }
        get_abt() {
            return new CustomIndicatorStrategy();
        }
        get abt() {
            return this.get_abt();
        }
        get_ab6() {
            return CustomIndicator.$;
        }
        get ab6() {
            return this.get_ab6();
        }
        aa5(a, b) {
            let c = this.xh(a, b);
            let d = this.xi(c);
            let e = new List$1(String_$type, 0);
            if (this.basedOnColumns != null) {
                let f = new FinancialEventArgs(c.calculateFrom, c.calculateCount, c, d, this);
                this.basedOnColumns(this, f);
                if (f.basedOn != null) {
                    for (let g of fromEnum(f.basedOn)) {
                        e.add(g);
                    }
                }
            }
            return e;
        }
        get indicator() {
            return this.acf;
        }
        set indicator(a) {
            this.acf = a;
            this.abd();
        }
        get basedOnColumns() {
            return this.ace;
        }
        set basedOnColumns(a) {
            this.ace = a;
        }
        aa2(a, b) {
            super.aa2(a, b);
            if (this.indicator != null) {
                let c = this.xh(a, b);
                if (b == 0) {
                    return false;
                }
                if (!this.yd(this.aa5(a, b))) {
                    return false;
                }
                this.indicator(this, new FinancialEventArgs(a, b, c, this.xi(c), this));
                if (this.abv(c) && this.xn != null) {
                    this.xn.c1();
                }
                return true;
            }
            return false;
        }
    }
    CustomIndicator.$t = markType(CustomIndicator, 'CustomIndicator', StrategyBasedIndicator.$);
    return CustomIndicator;
})();
